@@ -91,7 +91,7 @@ class GrobidConverter(ConverterBase):
                                         f.write(chunk)
                                 f.seek(0)
                                 doc = file_to_doc(
-                                    UploadFile(f.name, f, "application/pdf"), params, client
+                                    UploadFile(url.path, f, "application/pdf"), params, client
                                 )
                                 docs.append(doc)
 
@@ -133,6 +133,7 @@ def file_to_doc(source: UploadFile, params, client):
     r = process_fulltext_document.sync_detailed(client=client, multipart_data=form)
     if r.is_success:
         doc = article_to_doc(r, params)
+        doc.metadata['original'] = source.filename
     else:
         r.raise_for_status()
     return doc
